@@ -2,7 +2,8 @@
 #  License, v. 2.0. If a copy of the MPL was not distributed with this
 #  file, You can obtain one at https://mozilla.org/MPL/2.0/.
 import concurrent.futures
-from typing import Union
+from abc import ABCMeta, abstractmethod
+from typing import Union, Callable
 from bleak import BleakClient
 import asyncio
 from threading import Thread
@@ -11,7 +12,19 @@ from .bluetoothprofile.characteristics import Characteristic
 ByteData = Union[bytes, bytearray, memoryview]
 
 
-class ThreadEventLoop:
+class BluetoothEventLoop(metaclass=ABCMeta):
+    @abstractmethod
+    def run_async(self, coroutine) -> concurrent.futures.Future:
+        pass
+
+    @abstractmethod
+    def create_future(self) -> asyncio.Future:
+        pass
+
+
+class ThreadEventLoop(BluetoothEventLoop):
+    _singleton = None
+
     def __init__(self):
         self.loop = asyncio.new_event_loop()
         Thread(target=ThreadEventLoop._start_background_loop, args=(self.loop,), daemon=True).start()
@@ -27,19 +40,18 @@ class ThreadEventLoop:
     def create_future(self) -> asyncio.Future:
         return self.loop.create_future()
 
-
-class BluetoothEventLoop:
-    _single_thread = ThreadEventLoop()
-
     @staticmethod
     def single_thread():
-        return BluetoothEventLoop._single_thread
+        if not ThreadEventLoop._singleton:
+            ThreadEventLoop._singleton = ThreadEventLoop()
+
+        return ThreadEventLoop._singleton
 
 
 class BluetoothDevice:
 
-    def __init__(self, address: str, loop : BluetoothEventLoop = None):
-        self.loop = loop if loop else BluetoothEventLoop.single_thread()
+    def __init__(self, address: str, loop: BluetoothEventLoop = None):
+        self.loop = loop if loop else ThreadEventLoop.single_thread()
         self.client = BleakClient(address)
 
     def __enter__(self):
@@ -70,17 +82,17 @@ class BluetoothDevice:
         self.loop.run_async(self.client.write_gatt_char(characteristic.value, data)).result()
         print("written")
 
-    def notify(self, characteristic: Characteristic, callback) -> None:
-        def wrap_try_catch(fn):
-            def suggest_do_in_tkinter(*arg):
+    def notify(self, characteristic: Characteristic, callback: Callable[[int, bytearray], None]) -> None:
+        def wrap_try_catch(fn: Callable[[int, bytearray], None]):
+            def suggest_do_in_tkinter(sender: int, data: bytearray):
                 try:
-                    callback(*arg)
+                    fn(sender, data)
                 except RuntimeError as e:
                     message, = e.args
                     if message == "main thread is not in main loop":
                         raise RuntimeError(
-                            """You tried to call tkinter API from within a KaspersMicrobit notification callback. 
-                            This is probably not what you want. If your really want to do this wrap your callback in 
+                            """You tried to call tkinter API from within a KaspersMicrobit notification callback.
+                            This is probably not what you want. If your really want to do this wrap your callback in
                             kaspersmicrobit.tkinter.do_in_tkinter(tk, your_callback)""") from e
                     raise e
             return suggest_do_in_tkinter
